| Title: | Utilities for Small Box Game Jackets |
|---|---|
| Description: | Utilities for small box game jackets. |
| Authors: | Trevor L. Davis [aut, cre] (ORCID: <https://orcid.org/0000-0001-6341-4639>), Delapouite <https://delapouite.com/> [ill] ("Person icon" <https://game-icons.net/1x1/delapouite/person.html> and "Weight icon" <https://game-icons.net/1x1/delapouite/weight.html> / "CC BY 3.0" <https://creativecommons.org/licenses/by/3.0/>), Lorc <https://lorcblog.blogspot.com/> [ill] ("Clockwork icon" <https://game-icons.net/1x1/lorc/clockwork.html> / "CC BY 3.0" <https://creativecommons.org/licenses/by/3.0/>) |
| Maintainer: | Trevor L. Davis <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0-36 |
| Built: | 2026-05-21 21:00:06 UTC |
| Source: | https://github.com/trevorld/sbgjackets |
sbgjackets run-time system dependenciescheck_sbgjackets_dependencies() checks this sbgjackets
run-time system dependencies.
check_sbgjackets_dependencies()check_sbgjackets_dependencies()
sbgjackets has the following run-time system dependencies:
The Carlito font.
R compiled with support for the Cairo-devices i.e. cairo_pdf().
System tools to embed various pdf metadata such as exiftool, gs, and/or pdftk.
pcbj_bavarian_pattern() creates a playing card box jacket for a German-suited deck in the Bavarian pattern.
pcbj_castilian_pattern() creates a playing card box jacket for a Spanish-suited deck in the Castilian pattern.
pcbj_english_pattern() creates a playing card box jacket for a French-suited deck in the English pattern.
pcbj_bavarian_pattern( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_castilian_pattern( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_english_pattern( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )pcbj_bavarian_pattern( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_castilian_pattern( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_english_pattern( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
double |
If |
The output file name invisibly. As a side effect creates a pdf file.
pcbj_bridge() creates a playing card box jacket for a Bridge deck.
pcbj_pinochle() creates a playing card box jacket for a Pinochle deck.
pcbj_poker() creates a playing card box jacket for a Poker deck.
pcbj_bridge( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_pinochle( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_poker( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )pcbj_bridge( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_pinochle( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE ) pcbj_poker( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
double |
If |
The output file name invisibly. As a side effect creates a pdf file.
pcbj_cubes() creates a playing card box jacket for wooden cube storage.
pcbj_dice() creates a playing card box jacket for dice storage.
pcbj_meeples() creates a playing card box jacket for meeple storage.
pcbj_polyhedral_dice() creates a playing card box jacket for polyhedral dice storage.
pcbj_cubes( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) pcbj_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) pcbj_meeples( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) pcbj_polyhedral_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )pcbj_cubes( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) pcbj_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) pcbj_meeples( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) pcbj_polyhedral_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
The output file name invisibly. As a side effect creates a pdf file.
pcbj_decktet() creates a playing card box jacket for the Decktet.
pcbj_decktet( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )pcbj_decktet( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
double |
If |
The output file name invisibly. As a side effect creates a pdf file.
pcbj_everdeck() creates two playing card box jackets for the Everdeck.
pcbj_everdeck( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )pcbj_everdeck( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
The output file name invisibly. As a side effect creates a pdf file.
pcbj_fox_in_the_forest() creates a playing card box jacket for the game The Fox in the Forest.
pcbj_fox_in_the_forest( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )pcbj_fox_in_the_forest( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
double |
If |
Note that these print-and-play playing card box jackets are for Personal Use Only.
The output file name invisibly. As a side effect creates a pdf file.
pcbj_mahjong() creates two playing card box jackets for a deck of Mahjong cards.
pcbj_mahjong( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )pcbj_mahjong( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
The output file name invisibly. As a side effect creates a pdf file.
pcbj_qwixx() creates a playing card box jacket for the game Qwixx.
pcbj_qwixx( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )pcbj_qwixx( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
double |
If |
Note that these print-and-play playing card box jackets are for Personal Use Only.
The output file name invisibly. As a side effect creates a pdf file.
pcbj_wizard() creates a playing card box jacket for the game Wizard.
pcbj_wizard( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )pcbj_wizard( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, double = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
double |
If |
Note that these print-and-play playing card box jackets are for Personal Use Only.
The output file name invisibly. As a side effect creates a pdf file.
pdf_polish_jacket() polishes a jacket pdf by adding instructions and/or metadata.
pdf_polish_jacket(output, ..., instructions = FALSE, xmp = NULL)pdf_polish_jacket(output, ..., instructions = FALSE, xmp = NULL)
output |
Filename of a pdf file created by |
... |
Should be empty. |
instructions |
If |
xmp |
A |
The output filename invisibly
sbgj_black_stones() creates a small box game jacket for black stones.
sbgj_cubes() creates a small box game jacket for wooden cubes.
sbgj_glass_stones() creates a small box game jacket for glass stones.
sbgj_marbles() creates a small box game jacket for marbles.
sbgj_meeples() creates a small box game jacket for meeples.
sbgj_pawns() creates a small box game jacket for pawns.
sbgj_polyhedral_dice() creates a small box game jacket for polyhedral dice.
sbgj_reversible_discs() creates a small box game jacket for
reversible discs.
sbgj_white_stones() creates a small box game jacket for white stones.
sbgj_black_stones( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_cubes( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_marbles( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_glass_stones( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_meeples( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_pawns( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_polyhedral_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_reversible_discs( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_white_stones( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )sbgj_black_stones( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_cubes( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_marbles( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_glass_stones( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_meeples( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_pawns( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_polyhedral_dice( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_reversible_discs( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_white_stones( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
The output file name invisibly. As a side effect creates a pdf file.
sbgj_dominoes_double6(), sbgj_dominoes_double9(), and sbgj_dominoes_double12() creates a small box game jacket for Double-Six Dominoes, Double-Nine Dominoes, and Double-Twelve Dominoes.
sbgj_dominoes_all() creates all of those into a single pdf file.
sbgj_dominoes_all( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = TRUE ) sbgj_dominoes_double6( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_dominoes_double9( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_dominoes_double12( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )sbgj_dominoes_all( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = TRUE ) sbgj_dominoes_double6( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_dominoes_double9( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_dominoes_double12( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
The output file name invisibly. As a side effect creates a pdf file.
sbgj_dungeon_delver() creates a small box game jacket for
Dungeon Delver.
sbgj_dungeon_delver( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )sbgj_dungeon_delver( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
Note that this print-and-play small box game jacket is for Personal Use Only.
The output file name invisibly. As a side effect creates a pdf file.
sbgj_looney_pyramids() creates a small box game jacket for Looney Pyramids.
sbgj_homeworlds() creates a small box game jacket for Homeworlds.
sbgj_ice_duo() creates a small box game jacket for Ice Duo.
sbgj_jinxx() creates a small box game jacket for Jinxx.
sbgj_martian_chess() creates a small box game jacket for Martian Chess.
sbgj_nomids() creates a small box game jacket for Nomids.
sbgj_looney_pyramids( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_homeworlds( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_ice_duo( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_jinxx( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_martian_chess( output = NULL, ..., silver = FALSE, paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_nomids( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, custom = FALSE )sbgj_looney_pyramids( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_homeworlds( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_ice_duo( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_jinxx( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_martian_chess( output = NULL, ..., silver = FALSE, paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_nomids( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE, custom = FALSE )
output |
Output file name. Defaults to |
... |
Should be left empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
silver |
If |
custom |
If |
Note that these print-and-play small box game jackets are for Personal Use Only. These jackets use images by Looney Labs. These jackets are not for distribution. For more information see the Looney Labs FAQ: https://faq.looneylabs.com/non-gameplay-questions/working-with-looney-labs#1774.
The output file name invisibly. As a side effect creates a pdf file.
sbgj_nestortiles() creates a small box game jacket for
Nestortiles.
sbgj_shibumi() creates a small box game jacket for Shibumi.
sbgj_nestortiles( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_shibumi( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )sbgj_nestortiles( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE ) sbgj_shibumi( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
Note that these print-and-play small box game jackets are for Personal Use Only.
The output file name invisibly. As a side effect creates a pdf file.
sbgj_spirograph() creates a small box game jacket for
Spirograph.
sbgj_spirograph( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )sbgj_spirograph( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
Note that this print-and-play small box game jacket is for Personal Use Only.
The output file name invisibly. As a side effect creates a pdf file.
sbgj_yinsh() creates a small box game jacket for YINSH.
sbgj_yinsh( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )sbgj_yinsh( output = NULL, ..., paper = getOption("papersize", "letter"), instructions = FALSE )
output |
Output file name. Defaults to |
... |
Should be empty. |
paper |
Paper size. Usually either "letter" or "a4" but in certain circumstances can be one of "letter", "a4", "poker", "bridge", "legal", "a5", "a3", "special". |
instructions |
If |
Note that these print-and-play small box game jackets are for Personal Use Only.
The output file name invisibly. As a side effect creates a pdf file.
marquee stylesbgjackets_style() returns a marquee style set object
to help add text to jackets in a consistent style.
sbgjackets_style(size = c("4x6", "poker"), ..., color = "black")sbgjackets_style(size = c("4x6", "poker"), ..., color = "black")
size |
Either |
... |
Ignored |
color |
The desired text color. |
A marquee style set object.
backNotesGrob(), creditsGrob(), spineIconGrob(), and
spineTextGrob() are helper grob functions to help make small
box game jackets using pnpmisc::pdf_create_jacket().
spineTextGrob(title, col = "white", size = c("4x6", "poker")) creditsGrob( xmp = xmpdf::xmp(), credits = character(), icons = FALSE, size = "4x6", ..., width = NULL, x = NULL ) backNotesGrob( notes, col = "black", size = c("4x6", "poker"), ..., style = sbgjackets_style(size, color = col) ) spineIconGrob(players, minutes, weight, col = "white", size = "4x6")spineTextGrob(title, col = "white", size = c("4x6", "poker")) creditsGrob( xmp = xmpdf::xmp(), credits = character(), icons = FALSE, size = "4x6", ..., width = NULL, x = NULL ) backNotesGrob( notes, col = "black", size = c("4x6", "poker"), ..., style = sbgjackets_style(size, color = col) ) spineIconGrob(players, minutes, weight, col = "white", size = "4x6")
title |
Title of small box game jacket (usually game name) |
col |
Color of text/icons |
size |
Target box size. Either |
xmp |
A |
credits |
A character vector of (commonmark) credits to eventually be
passed to |
icons |
If |
... |
Ignored for now. |
x, width
|
|
notes |
A character vector of (commonmark) back cover notes.
Will be collapsed to a single string by |
style |
A |
players |
A integer vector of allowed number of players |
minutes |
An integer of number of minutes (larger number from BGG) |
weight |
A double of game weight (number from BGG) |
A grid grob object
library("grid", include.only = c("gList", "gpar")) sbgj_example <- function(output = NULL) { front <- fullGrob("#D55E00") back <- fullGrob("#009E73") spine <- gList(fullGrob("black"), spineTextGrob("Example Spine"), spineIconGrob(2:4, 30, 1.5)) inner <- creditsGrob(icons = TRUE) pnpmisc::pdf_create_jacket(output, front = front, back = back, spine = spine, inner = inner) }library("grid", include.only = c("gList", "gpar")) sbgj_example <- function(output = NULL) { front <- fullGrob("#D55E00") back <- fullGrob("#009E73") spine <- gList(fullGrob("black"), spineTextGrob("Example Spine"), spineIconGrob(2:4, 30, 1.5)) inner <- creditsGrob(icons = TRUE) pnpmisc::pdf_create_jacket(output, front = front, back = back, spine = spine, inner = inner) }